# -*- encoding: utf-8 -*-
# vim: set fdm=indent ts=4 sw=4 sts=4 et ai tw=80 cc=+0 mouse=a nu : #

from msspec.calculator import MSSPEC, XRaySource
from msspec.utils      import *

from ase import Atoms

import numpy as np

# Defining global variables
a0        = 6.0
symbols   = ('Rh', 'O')
ke        = 723.
level     = '1s'

data = None
for symbol in symbols:
    cluster = Atoms(symbol*2, positions = [(0,0,0), (0,0,a0)])
    [a.set('mt_radius', 1.5) for a in cluster]

    # Create the calculator
    calc = MSSPEC(spectroscopy = 'PED')
    calc.source_parameters.energy = XRaySource.AL_KALPHA
    calc.set_atoms(cluster)
    cluster.absorber = 0

    # compute
    data = calc.get_scattering_factors(level=level, kinetic_energy=ke, data=data)
    
data.view()
